@@ -15,12 +15,12 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GENA_PROTOCOL_H__
-#define __GENA_PROTOCOL_H__
+#ifndef GUPNP_GENA_PROTOCOL_H
+#define GUPNP_GENA_PROTOCOL_H
 
 G_BEGIN_DECLS
 
@@ -34,4 +34,4 @@ G_BEGIN_DECLS
 
 G_END_DECLS
 
-#endif /* __GENA_PROTOCOL_H__ */
+#endif /* GUPNP_GENA_PROTOCOL_H */
